---
title: 'application:maintenance'
url: 'https://docs.danami.com/warden/command-line-interface/application/application-maintenance'
markdown: 'https://docs.danami.com/warden/command-line-interface/application/application-maintenance.md'
date: '2026-10-07'
description: 'Configure the panel maintenance settings. warden --task=application:maintenance Option Value Default Description --prune_action_logs <digit> 90 A nightly task to prune action logs older than this number of days. --prune_application_logs <digit> 90 A nightly task to prune application …'
taxonomy:
  category:
    - docs
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Application       application:maintenance    

# application:maintenance

Configure the panel maintenance settings.

```
warden --task=application:maintenance
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--prune_action_logs` | <digit> | 90 | A nightly task to prune action logs older than this number of days. |
| `--prune_application_logs` | <digit> | 90 | A nightly task to prune application debug logs older than this number of days. |
| `--prune_message_logs` | <digit> | 45 | A nightly task to prune message logs older than this number of days. |
| `--prune_quarantine` | <digit> | 30 | A nightly task to prune quarantined data older than this number of days. |
| `--prune_spam_folders` | <digit> | 30 | A nightly task to prune messages that have been moved to a mailboxes spam folder older than this number of days. |
| `--prune_statistics` | <digit> | 365 | A nightly task to prune statistics older than this number of days. |
| `--prune_txrep` | <digit> | 365 | A nightly task to prune AWL or TxRep reputation data older than this number of days. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |

## Examples

```
// set prune_spam_folders to every 60 days
warden --task=application:maintenance --prune_spam_folders=60

// reset the prune_spam_folders back to its default value
warden --task=application:maintenance --default_option=prune_spam_folders

// reset all settings to their default values
warden --task=application:maintenance --default=yes

// keep message logs for 90 days and quarantine data for 14 days
warden --task=application:maintenance --prune_message_logs=90 --prune_quarantine=14
```

 [ ](https://docs.danami.com/warden/command-line-interface/application/application-license) [](https://docs.danami.com/warden/command-line-interface/application/application-maintenance-database)

---

## Navigation

- Previous: [application:license](https://docs.danami.com/warden/command-line-interface/application/application-license.md)
- Next: [application:maintenance:database](https://docs.danami.com/warden/command-line-interface/application/application-maintenance-database.md)
